tietools.add_or_remove_tie_chain_notes_to_achieve_written_duration
==================================================================

.. autofunction:: abjad.tools.tietools.add_or_remove_tie_chain_notes_to_achieve_written_duration
